/**
 * 依赖 mui的弹窗   swiper的滑动  jquery
 * @param {Object} options
 */
function AddressCascade(options) {
	this.options = $.extend(true, {
		cascadeId: 'address-Cascade',
		cssName: {
			province: 'cascade-province',
			city: 'cascade-city',
			town: 'cascade-town',
			wrapper: 'swiper-wrapper'
		}
	}, options);
	this.init();
}
AddressCascade.prototype = {
	init: function() {
		var self = this;
		self.event();
	},
	event: function() {
		this.initPopup();

	},
	// 弹出窗口
	initPopup: function() {
		var self = this;
		var $cascade = self.get$Cascade();
		var popup = function() {
			app.Post({
				url: self.options.province.url,
				data: {}
			}, null, function(data) {
				self.renderProvince(data.List);
				self.options.popup(self.options.cascadeId);
				self.initCancel();
				self.initSure();
			});
		};
		$('#' + self.options.id).off('click').on('click', function() {
			if(!!$('#' + self.options.cascadeId).get(0)) {
				popup();
			} else {
				$('#' + self.options.id).after(self.getCascadeHTML());
				popup();
			}

		});
	},
	initCancel: function() {
		var self = this;
		var $cancel = self.get$Cascade().find('.btn-cancel');
		$cancel.off('click').on('click', function() {
			self.options.popup(self.options.cascadeId);
		});
	},
	initSure: function() {
		var self = this;
		var $cascade = self.get$Cascade();
		var $sure = $cascade.find('.btn-sure');
		var cssName = self.options.cssName;
		$sure.off('click').on('click', function() {
			var $p = $cascade.find('.' + cssName.province + '  .swiper-slide-active');
			var $c = $cascade.find('.' + cssName.city + '  .swiper-slide-active');
			var $t = $cascade.find('.' + cssName.town + '  .swiper-slide-active');
			var data = {
				p: {
					name: $p.html() || '',
					value: $p.attr('data-value') || ''
				},
				c: {
					name: $c.html() || '',
					value: $c.attr('data-value') || ''
				},
				t: {
					name: $t.html() || '',
					value: $t.attr('data-value') || ''
				}
			};

			self.options.chooseCallbackFn(data);
			self.options.popup(self.options.cascadeId);
		});
	},
	// 初始化级联的值，暂时不实现
	initCascadeValue: function() {

	},
	get$C: function() {
		return $('#' + this.options.id);
	},
	get$Cascade: function() {
		return $('#' + this.options.cascadeId);
	},
	get$CascadeItem: function(cssName) {
		return this.get$Cascade().find('.' + cssName);
	},
	get$ProvinceSwiper: function() {
		return this.get$CascadeItem(this.options.cssName.province).data('mySwiper');
	},
	get$CitySwiper: function() {
		return this.get$CascadeItem(this.options.cssName.city).data('mySwiper');
	},
	get$TownSwiper: function() {
		return this.get$CascadeItem(this.options.cssName.town).data('mySwiper');
	},
	get$wrapper: function($el) {
		return $el.find('.' + this.options.cssName.wrapper);
	},
	getCascadeHTML: function() {
		var cssName = this.options.cssName;
		var wrapper = cssName.wrapper;
		return '<div id="' + this.options.cascadeId + '" class="mui-popover mui-popover-bottom mui-popover-action cascade-container" style="border-radius:0;">' +
			'			<!-- 可选择菜单 -->' +
			'			<div class="mui-table-view">' +
			'				<div class="cascade-header">' +
			'					<a href="javascript:void(0)"  class="btn-cancel">取消</a>' +
			'						' +
			'					<a href="javascript:void(0)" class="btn-sure">确定</a>' +
			'				</div>' +
			'				<div class="cascade-body" >' +
			'					<div class="' + cssName.province + ' swiper-container cascade-item">' +
			'						<div class="' + wrapper + '"></div>' +
			'					</div>' +
			'					<div class="' + cssName.city + ' cascade-item swiper-container">' +
			'						<div class="' + wrapper + '"></div>' +
			'					</div>' +
			'					<div class="' + cssName.town + ' cascade-item swiper-container">' +
			'						<div class="' + wrapper + '"></div>' +
			'					</div>' +
			'					<div class="line"></div>' +
			'				</div>' +
			'			</div>' +
			'		</div>';
	},
	renderProvince: function(provinceData) {
		var self = this;
		self.renderCascade(self.options.cssName.province,
			'province',
			provinceData,
			self.options.province.value,
			self.options.city,
			function(cityData) {
				if(!!self.get$CitySwiper()) {
					self.get$CitySwiper().removeAllSlides();
					self.get$CitySwiper().updateSlidesSize();
				}
				self.renderCity(cityData);
			})
	},
	renderCity: function(cityData) {
		var self = this;
		self.renderCascade(self.options.cssName.city,
			'city', cityData, self.options.city.value, self.options.town,
			function(townData) {
				if(!!self.get$TownSwiper()) {
					self.get$TownSwiper().removeAllSlides();
					self.get$TownSwiper().updateSlidesSize();
				}
				self.renderTown(townData);
			})
	},
	renderTown: function(townData) {
		this.renderCascade(this.options.cssName.town,
			'town', townData, this.options.town.value);
		this.options.province.value = 0;
		this.options.city.value = 0;
	},
	renderCascade: function(cssName, type, _data, selectValue, apiOption, callbackFn) {
		var self = this;
		var $el = self.get$CascadeItem(cssName);
		var $wrapper = self.get$wrapper($el);
		var tHtml = '';
		var mySwiper;
		var currCascade = self.get$C().data('data') || {};
		var currIndex = null;
		$.each(_data, function(i, d) {
			var _d = self.options.dataToUI(d);
			switch(type) {
				case 'province':
					if(_d.value == currCascade.p) {
						currIndex = i;
					}
					break;
				case 'city':
					if(_d.value == currCascade.c) {
						currIndex = i;
					}
					break;
				case 'town':
					if(_d.value == currCascade.t) {
						currIndex = i;
					}
					break;
				default:
					break;
			}
			tHtml += ('<div class="swiper-slide" data-value="' + _d.value + '">' + _d.name + '</div>');
		});

		var runLastCascade = function(value) {
			if(!!apiOption && !!apiOption.url && !!apiOption.apiParamName) {
				var _apiOption = {
					url: apiOption.url,
					data: {}
				};
				_apiOption.data[apiOption.apiParamName + ''] = value;
				app.Post(_apiOption, null, function(result) {
					var lastData = result.List;
					callbackFn(lastData);
				});
			}
		}
		if(!$el.data('mySwiper')) {
			$wrapper.html(tHtml);
			mySwiper = new Swiper('.' + cssName, {
				direction: 'vertical',
				height: 30,
				centeredSlides: true,
				spaceBetween: 0,
				freeModeSticky: true,
				onInit: function(_swiper) {
					if(!!apiOption) {
						selectValue = selectValue || _data[0][apiOption.valueName];
						runLastCascade(selectValue);
					}
				},
				onTransitionEnd: function(_swiper) {
					runLastCascade($el.find('.swiper-slide-active').attr('data-value'));
				}
			});
			$el.data('mySwiper', mySwiper);
			$el.off().on('click', '.swiper-slide', function() {
				var index = $el.find('.swiper-slide').index($(this));
				mySwiper.slideTo(index, 600, function() {});
			});
		} else {
			mySwiper = $el.data('mySwiper');
			mySwiper.appendSlide(tHtml);
			mySwiper.updateSlidesSize();
			if(!!apiOption) {
				selectValue = selectValue || _data[0][apiOption.valueName];
				runLastCascade(selectValue);
			}
		}
		var selectIndex = $el.find('.swiper-slide').filter("[data-value='" + selectValue + "']").index();
		selectIndex = selectIndex > 0 ? selectIndex : (currIndex || 0);
		mySwiper.slideTo(selectIndex, 0, function() {});
	}

}